@@ -1,6 +1,6 @@
 /*
 Weborf
-Copyright (C) 2009  Salvo "LtWorf" Tomaselli
+Copyright (C) 2009-2018  Salvo "LtWorf" Tomaselli
 
 Weborf is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,7 +20,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef BUFFERED_READER_H
 #define BUFFERED_READER_H
 
+#include <stdbool.h>
 #include <unistd.h>
+
+#include "types.h"
+
 typedef struct {
     char *buffer;   //Buffer where the reader stores the read data
     char *start;    //Pointer to non-consumed data
@@ -31,6 +35,6 @@ typedef struct {
 void buffer_reset (buffered_read_t * buf);
 int buffer_init(buffered_read_t * buf, ssize_t size);
 void buffer_free(buffered_read_t * buf);
-ssize_t buffer_read(int fd, void *b, ssize_t count, buffered_read_t * buf);
-size_t buffer_strstr(int fd, buffered_read_t * buf, char * needle);
+ssize_t buffer_read(fd_t fd, void *b, ssize_t count, buffered_read_t * buf);
+size_t buffer_strstr(fd_t fd, buffered_read_t * buf, char * needle);
 #endif
