@@ -1,6 +1,6 @@
 /*
 Weborf
-Copyright (C) 2007-2018  Salvo "LtWorf" Tomaselli
+Copyright (C) 2007-2019  Salvo "LtWorf" Tomaselli
 
 Weborf is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -274,13 +274,14 @@ Prints version information
 */
 void version() {
     printf("Weborf %s\n"
-           "Copyright (C) 2007-2018 Salvo 'LtWorf' Tomaselli.\n"
+           "Copyright (C) 2007-2019 Salvo 'LtWorf' Tomaselli.\n"
            "This is free software.  You may redistribute copies of it under the terms of\n"
            "the GNU General Public License <http://www.gnu.org/licenses/gpl.html>.\n"
            "There is NO WARRANTY, to the extent permitted by law.\n\n"
 
            "Written by Salvo 'LtWorf' Tomaselli and Salvo Rinaldi.\n"
            "Synchronized queue by Prof. Giuseppe Pappalardo.\n\n"
+
            "http://ltworf.github.io/weborf/\n", VERSION);
     exit(0);
 }
@@ -379,9 +380,9 @@ void help() {
            "  -g  --gid     followed by a valid gid\n"
            "  -V, --virtual list of virtualhosts in the form host=basedir, comma-separated\n"
            "  -v, --version print program version\n"
-           "  -x, --noexec  tells weborf to send each file instead of executing scripts\n"
            "  -S, --cert    the certificate to use\n"
            "  -K, --key     the private key to use with the certificate\n"
+           "  -Y, --yesexec enables CGI\n"
            "\n"
            "Report bugs here https://bugs.launchpad.net/weborf\n"
            "or to " PACKAGE_BUGREPORT "\n");
@@ -437,7 +438,7 @@ http_param is the string containing the header
 parameter is the searched parameter
 buf is the buffer where copy the value
 size, maximum size of the buffer
-param_len =lenght of the parameter
+param_len =length of the parameter
 
 Returns false if the parameter isn't found, or true otherwise
 */
