@@ -241,13 +241,13 @@ static inline int printprops(fd_t sock, char *page, u_dav_details props,char* fi
     pagesize += printf_s;
 
     if (props.dav_details.getetag) {
-        printf_s = snprintf(xml + pagesize, maxsize, "<D:getetag>%ld</D:getetag>\n", stat_s.st_mtime);
+        printf_s = snprintf(xml + pagesize, maxsize, "<D:getetag>%lld</D:getetag>\n", stat_s.st_mtime);
         maxsize -= printf_s;
         pagesize += printf_s;
     }
 
     if (props.dav_details.getcontentlength) {
-        printf_s = snprintf(xml + pagesize, maxsize, "<D:getcontentlength>%ld</D:getcontentlength>\n", stat_s.st_size);
+        printf_s = snprintf(xml + pagesize, maxsize, "<D:getcontentlength>%lld</D:getcontentlength>\n", stat_s.st_size);
         maxsize -= printf_s;
         pagesize += printf_s;
     }
